==> campsite-2.4.1.tbz: campsite/www-common/html/priv/lang/sh/pub.php <==
<?php
regGS("Publication List", "Lista publikacija");
regGS("Go To Issues", "Idi na izdanja");
regGS("Name<BR><SMALL>(click to see issues)</SMALL>", "Ime<br><small>(kliknite za pregled izdanja)</small>");
regGS("Delete publication $1", "Obriši publikaciju $1");
regGS("No publications.", "Nema publikacija");
regGS("Default Site Alias", "Osnovni sajt alias");
regGS("URL Type", "Tip URLa");
regGS("Country<BR><SMALL>(click to edit)</SMALL>", "Država<br><small>(kliknite za uređivanje)</small>");
regGS("Delete alias $1", "Obriši podatak $1");
regGS("Configure publication", "Podesi publikaciju");
regGS("You do not have the right to edit publication information.", "Nemate pravo да uređuјете podatkе o publikaciji");
regGS("General attributes", "Opšti atributi");
regGS("Subscriptions defaults", "Osnovni podaci o pretplatama");
regGS("Countries defaults", "Osnovni podaci o državama");
regGS("Changing publication information", "Menjanje podataka o publikaciji");
regGS("You do not have the right to change publication information.", "Nemate pravo izmene podataka o publikaciji.");
regGS("The publication information could not be updated.", "Podaci o publikaciji ne mogu biti izmenjeni.");
regGS("Please check if another publication with the same name or the same site name does not already exist.", "Proverite da li već postoji publikacija sa istim imenom ili imenom sajta .");
regGS("You do not have the right to delete publications.", "Nemate pravo da brišete publikacije");
regGS("Are you sure you want to delete the publication $1?", "Sigurni ste da želite da obrišete publikaciju $1?");
regGS("Deleting publication", "Brisanje publikacije");
regGS("There are $1 subscription(s) left.", "Preostalo je $1 pretplata.");
regGS("The publication $1 could not be deleted.", "Publikacija $1 ne možebiti obrisana.");
regGS("Adding new publication", "Dodavanje nove publikacije");
regGS("The publication could not be added.", "Publikacija ne može biti dodata.");
regGS("Select the publication", "Izaberite publikaciju");
regGS("Add new country default subscription time", "Dodaj novi osnovni period pretplate za državu");
regGS("You do not have the right to manage publications.", "Nemate pravo da administrirate publikacijama.");
regGS("Please check if another entry with the same country code exists already.", "Proverite da li več postoji unos sa istim kodom države.");
regGS("Adding new country default subscription time", "Dodavanje novog osnovnog perioda pretplate za državu");
regGS("You must select a country.", "Morate izabrati državu.");
regGS("The default subscription time for country $1 could not be added.", "Novi period pretplate za $1 ne može biti dodat.");
regGS("Change subscription default time", "Promeni trajanje osnovne pretplate");
regGS("Default subscription time for $1 changed", "Trajanje osnovne pretplate za $1 promenjeno");
regGS("Are you sure you want to delete the subscription default time for $1?", "Sigurni ste da želite da obrišete osnovnu dužinu pretplate za $1?");
regGS("Subscription default time for $1 deleted", "Dužina pretplate za $1 je izbrisana");
regGS("Name<BR><SMALL>(click to select the publication)</SMALL>", "Naziv<br><small>(kliknite za izbor publikacije)</small>");
regGS("Add new alias", "Dodaj novi alias");
regGS("Alias (click to edit)", "Alias (klik za uređivanje)");
regGS("Edit aliases", "Uredi aliase");
regGS("Publication Aliases", "Aliasi za publikaciju");
regGS("Adding new alias", "Dodavanje novih aliasa");
regGS("The site alias $1 has been added to publication $2.", "Sajt alias $1 dodat je publikaciji $2.");
regGS("The site alias $1 could not be added.", "Sajt alias $1 ne može biti dodat.");
regGS("Another alias with the same name exists already.", "Takav alias već postoji.");
regGS("Edit alias", "Uredi alias");
regGS("Editing alias", "Uređivanje aliasa");
regGS("The site alias for publication $1 has been modified to $2.", "Sajt alias za publikaciju $1 je promenjen u $2.");
regGS("The site alias $1 could not be modified.", "Sajt alias $1 ne može biti promenjen.");
regGS("Are you sure you want to delete the alias $1?", "Sigurni ste da želite da obrišete alias $1?");
regGS("Deleting alias", "Brisanje aliasa");
regGS("The alias $1 could not be deleted.", "Alias $1  ne može biti obrisan.");
regGS("The alias $1 has been deleted from publication $2.", "Alias $1 je obrisan iz publikacije $2.");
regGS("$1 is the default publication alias, it can not be deleted.", "$1 je osnovni alias publikacije i ne može biti obrisan!");
regGS("You do not have the right to add publications.", "Nemate pravo da dodajete publikacije.");
regGS("There are $1 issue(s) left.", "Preostalo je $1 izdanja.");
?>

==> campsite-2.6.1.tbz: campsite/www-common/html/priv/lang/sh/pub.php <==
<?php 
regGS("Use CAPTCHA to prevent spam?", "");
regGS("Public allowed to comment?", "");
regGS("Enable spam blocking?", "");
regGS("The subscription settings for '$1' could not be added.", "");
regGS("The publication name you specified conflicts with publication '$1'.", "");
regGS("The publication alias you specified conflicts with publication '$1'.", "");
regGS("Subscription defaults", "");
regGS("Subscription Settings by Country", "");
regGS("Set subscription settings for a country", "");
regGS("Set subscription settings by country", "");
regGS("Default time periods:", "");
regGS("Country subscription settings updated.", "");
regGS("Country subscription settings deleted.", "");
regGS("Change country subscription settings", "");
regGS("Are you sure you want to delete the subscription settings for $1?", "");
regGS("Publication updated", "");
regGS("Subscriber comments moderated?", "");
regGS("Public comments moderated?", "");
regGS("Comments enabled?", "");
regGS("Comments enabled", "");
regGS("Article comments default to enabled?", "");
regGS("trial subscription", "probna pretplata");
regGS("paid subscription", "plaćena pretplata");
regGS("time units", "vremenske jedinice");
regGS("one language", "jedan jezik");
regGS("all languages", "svi jezici");
regGS("Trial subscriptions", "Probne pretplate");
regGS("Time unit cost per one section", "Cena po vremenskoj jedinici za rubriku");
regGS("Paid subscriptions", "Plaćene pretplate");
regGS("Default time period", "Podrazumevani vremenski period");
regGS("Go To Issues", "Idi na izdanja");
regGS("Name<BR><SMALL>(click to see issues)</SMALL>", "Ime<br><small>(kliknite za pregled izdanja)</small>");
regGS("Delete publication $1", "Obriši publikaciju $1");
regGS("No publications.", "Nema publikacija");
regGS("Default Site Alias", "Osnovni sajt alias");
regGS("URL Type", "Tip URLa");
regGS("Country<BR><SMALL>(click to edit)</SMALL>", "Država<br><small>(kliknite za uređivanje)</small>");
regGS("Delete alias $1", "Obriši alias $1");
regGS("Configure publication", "Podesi publikaciju");
regGS("You do not have the right to edit publication information.", "Nemate pravo dа uređuјеtе podatkе o publikaciji.");
regGS("General attributes", "Opšti atributi");
regGS("You do not have the right to change publication information.", "Nemate pravo izmene podataka o publikaciji.");
regGS("The publication information could not be updated.", "Podaci o publikaciji ne mogu biti izmenjeni.");
regGS("You do not have the right to delete publications.", "Nemate pravo da brišete publikacije");
regGS("Are you sure you want to delete the publication $1?", "Sigurni ste da želite da obrišete publikaciju $1?");
regGS("Deleting publication", "Brisanje publikacije");
regGS("There are $1 subscription(s) left.", "Preostalo je $1 pretplata.");
regGS("The publication $1 could not be deleted.", "Publikacija $1 ne može biti obrisana.");
regGS("The publication could not be added.", "Publikacija ne može biti dodata.");
regGS("You do not have the right to manage publications.", "Nemate pravo da administrirate publikacijama.");
regGS("You must select a country.", "Morate izabrati državu.");
regGS("Default subscription time for $1 changed", "Trajanje osnovne pretplate za $1 promenjeno");
regGS("Subscription default time for $1 deleted", "Dužina pretplate za $1 je izbrisana");
regGS("Add new alias", "Dodaj novi alias");
regGS("Alias (click to edit)", "Alias (klik za uređivanje)");
regGS("Edit aliases", "Uredi aliase");
regGS("Publication Aliases", "Aliasi za publikaciju");
regGS("Adding new alias", "Dodavanje novih aliasa");
regGS("The site alias $1 has been added to publication $2.", "Sajt alias $1 dodat je publikaciji $2.");
regGS("The site alias $1 could not be added.", "Sajt alias $1 ne može biti dodat.");
regGS("Another alias with the same name exists already.", "Takav alias već postoji.");
regGS("Edit alias", "Uredi alias");
regGS("Editing alias", "Uređivanje aliasa");
regGS("The site alias for publication $1 has been modified to $2.", "Sajt alias za publikaciju $1 je promenjen u $2.");
regGS("The site alias $1 could not be modified.", "Sajt alias $1 ne može biti promenjen.");
regGS("Are you sure you want to delete the alias $1?", "Sigurni ste da želite da obrišete alias $1?");
regGS("Deleting alias", "Brisanje aliasa");
regGS("The alias $1 could not be deleted.", "Alias $1  ne može biti obrisan.");
regGS("The alias $1 has been deleted from publication $2.", "Alias $1 je obrisan iz publikacije $2.");
regGS("$1 is the default publication alias, it can not be deleted.", "$1 je osnovni alias publikacije i ne može biti obrisan!");
regGS("You do not have the right to add publications.", "Nemate pravo da dodajete publikacije.");
regGS("There are $1 issue(s) left.", "Preostalo je $1 izdanja.");
regGS("Time Unit", "Vremenska jedinica");
regGS("Currency", "Valuta");
regGS("Edit languages", "Uredi jezike");
?>
